# Robot Framework KafkaLibrary
## Introduction
KafkaLibrary is a [Robot Framework](http://robotframework.org/) library to interface with [Apache Kafka](https://kafka.apache.org/).

More information about this library can be found in the [Keyword Documentation](https://rawgit.com/s4int/robotframework-KafkaLibrary/master/doc/KafkaLibrary.html).

## Installation
### Using pip
```bash
      pip install -U robotframework-kafkalibrary
```

### Manual installation
1. Make sure you have [Robot Framework installed](http://code.google.com/p/robotframework/wiki/Installation).
2. Download source distributions (`*.tar.gz`) for the library and its dependencies:
      - https://pypi.python.org/pypi/robotframework-kafkalibrary
3. Extract each source distribution to a temporary location.
4. Go each created directory from the command line and install each project using:

```bash
      python setup.py install
```